@@ -24,7 +24,7 @@ from .utils.selenium_core import SeleniumDriverCore
 
 class SmartDriver(SeleniumDriverCore):
     def __init__(self, driver, api_key, initialization_dict={}):
-        self.version = 'appium-0.1.22'
+        self.version = 'appium-0.1.24'
         self.root_elem = None
         caps = driver.desired_capabilities
         self.automation_name = caps.get('automationName', '')
@@ -37,7 +37,7 @@ class SmartDriver(SeleniumDriverCore):
         screenshotBase64 = self._get_screenshot()
         im = Image.open(io.BytesIO(base64.b64decode(screenshotBase64)))
         width, height = im.size
-        self.multiplier = 1.0 * width / window_size['width']
+        self.multiplier = max(1.0, 1.0 * width / window_size['width'])
         self.is_espresso = self.automation_name.lower() == 'espresso'
         self.is_ios = self.automation_name.lower() == 'xcuitest'
 
