@@ -63,11 +63,13 @@ class SeleniumDriverCore(object):
         self.url = initialization_options.get('server_url',
                 os.environ.get('DEVTOOLSAI_URL', 'https://smartdriver.dev-tools.ai'))
         self.default_prod_url = 'https://smartdriver.dev-tools.ai'
+        self.scanner = None
         try:
-            # TODO(etienne): This doesn't work on Appium.
-            self.scanner = Scanner(self, self.driver, self.url, self.api_key)
+            if self._driver_type == 'selenium':
+                self.scanner = Scanner(self, self.driver, self.url, self.api_key)
         except Exception:
-            self.scanner = None
+            pass
+
 
         test_case_name = initialization_options.get('test_case_name', None)
         if test_case_name is None:
@@ -430,7 +432,8 @@ class SeleniumDriverCore(object):
                 'os': platform.platform(),
                 'sdk_version': self.version,
                 'language': 'python3-' + sys.version,
-                'test_case_name': self.test_case_uuid}
+                'test_case_name': self.test_case_uuid,
+                'automation_name': self.automation_name}
         try:
             res = requests.post(self.url + '/ping', json=data, timeout=3, verify=False)
             res = res.json()
@@ -469,7 +472,7 @@ class SeleniumDriverCore(object):
         except Exception:
             pass
 
-    def get_screenshot_hash(self, b64_screenshot):
+    def get_screenshot_hash(self, b64_screenshot, is_appium=False):
         """
         Get the screenshot uuid from the base64 encoded screenshot
         """
@@ -564,6 +567,9 @@ class SeleniumDriverCore(object):
                         'screenshot': screenshotBase64,
                         'label': element_name,
                         'test_case_name': self.test_case_uuid}
+                if self._driver_type == 'appium':
+                    data['is_appium'] = True
+                    del data['screenshot_uuid']
                 upload_screenshot_url = self.url + '/upload_screenshot'
                 start = time.time()
                 for _ in range(2):
@@ -622,6 +628,8 @@ class SeleniumDriverCore(object):
                 'screenshot': screenshotBase64,
                 'label': label,
                 'is_interactive': True}
+        if self._driver_type == 'appium':
+            data['is_appium'] = True
         for _ in range(2):
             try:
                 res = requests.post(url, json=data, verify=False, timeout=6).json()
